import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleBotManagement = new cloudflare.BotManagement("example_bot_management", {
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     aiBotsProtection: "block",
 *     crawlerProtection: "enabled",
 *     enableJs: true,
 *     fightMode: true,
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/botManagement:BotManagement example '<zone_id>'
 * ```
 */
export declare class BotManagement extends pulumi.CustomResource {
    /**
     * Get an existing BotManagement resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: BotManagementState, opts?: pulumi.CustomResourceOptions): BotManagement;
    /**
     * Returns true if the given object is an instance of BotManagement.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is BotManagement;
    /**
     * Enable rule to block AI Scrapers and Crawlers.
     * Available values: "block", "disabled".
     */
    readonly aiBotsProtection: pulumi.Output<string | undefined>;
    /**
     * Automatically update to the newest bot detection models created by Cloudflare as they are released. [Learn more.](https://developers.cloudflare.com/bots/reference/machine-learning-models#model-versions-and-release-notes)
     */
    readonly autoUpdateModel: pulumi.Output<boolean | undefined>;
    /**
     * Enable rule to punish AI Scrapers and Crawlers via a link maze.
     * Available values: "enabled", "disabled".
     */
    readonly crawlerProtection: pulumi.Output<string | undefined>;
    /**
     * Use lightweight, invisible JavaScript detections to improve Bot Management. [Learn more about JavaScript Detections](https://developers.cloudflare.com/bots/reference/javascript-detections/).
     */
    readonly enableJs: pulumi.Output<boolean | undefined>;
    /**
     * Whether to enable Bot Fight Mode.
     */
    readonly fightMode: pulumi.Output<boolean | undefined>;
    /**
     * Whether to optimize Super Bot Fight Mode protections for Wordpress.
     */
    readonly optimizeWordpress: pulumi.Output<boolean | undefined>;
    /**
     * Super Bot Fight Mode (SBFM) action to take on definitely automated requests.
     * Available values: "allow", "block", "managedChallenge".
     */
    readonly sbfmDefinitelyAutomated: pulumi.Output<string | undefined>;
    /**
     * Super Bot Fight Mode (SBFM) action to take on likely automated requests.
     * Available values: "allow", "block", "managedChallenge".
     */
    readonly sbfmLikelyAutomated: pulumi.Output<string | undefined>;
    /**
     * Super Bot Fight Mode (SBFM) to enable static resource protection.
     * Enable if static resources on your application need bot protection.
     * Note: Static resource protection can also result in legitimate traffic being blocked.
     */
    readonly sbfmStaticResourceProtection: pulumi.Output<boolean | undefined>;
    /**
     * Super Bot Fight Mode (SBFM) action to take on verified bots requests.
     * Available values: "allow", "block".
     */
    readonly sbfmVerifiedBots: pulumi.Output<string | undefined>;
    /**
     * A read-only field that shows which unauthorized settings are currently active on the zone. These settings typically result from upgrades or downgrades.
     */
    readonly staleZoneConfiguration: pulumi.Output<outputs.BotManagementStaleZoneConfiguration>;
    /**
     * Whether to disable tracking the highest bot score for a session in the Bot Management cookie.
     */
    readonly suppressSessionScore: pulumi.Output<boolean>;
    /**
     * A read-only field that indicates whether the zone currently is running the latest ML model.
     */
    readonly usingLatestModel: pulumi.Output<boolean>;
    /**
     * Identifier.
     */
    readonly zoneId: pulumi.Output<string>;
    /**
     * Create a BotManagement resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: BotManagementArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering BotManagement resources.
 */
export interface BotManagementState {
    /**
     * Enable rule to block AI Scrapers and Crawlers.
     * Available values: "block", "disabled".
     */
    aiBotsProtection?: pulumi.Input<string>;
    /**
     * Automatically update to the newest bot detection models created by Cloudflare as they are released. [Learn more.](https://developers.cloudflare.com/bots/reference/machine-learning-models#model-versions-and-release-notes)
     */
    autoUpdateModel?: pulumi.Input<boolean>;
    /**
     * Enable rule to punish AI Scrapers and Crawlers via a link maze.
     * Available values: "enabled", "disabled".
     */
    crawlerProtection?: pulumi.Input<string>;
    /**
     * Use lightweight, invisible JavaScript detections to improve Bot Management. [Learn more about JavaScript Detections](https://developers.cloudflare.com/bots/reference/javascript-detections/).
     */
    enableJs?: pulumi.Input<boolean>;
    /**
     * Whether to enable Bot Fight Mode.
     */
    fightMode?: pulumi.Input<boolean>;
    /**
     * Whether to optimize Super Bot Fight Mode protections for Wordpress.
     */
    optimizeWordpress?: pulumi.Input<boolean>;
    /**
     * Super Bot Fight Mode (SBFM) action to take on definitely automated requests.
     * Available values: "allow", "block", "managedChallenge".
     */
    sbfmDefinitelyAutomated?: pulumi.Input<string>;
    /**
     * Super Bot Fight Mode (SBFM) action to take on likely automated requests.
     * Available values: "allow", "block", "managedChallenge".
     */
    sbfmLikelyAutomated?: pulumi.Input<string>;
    /**
     * Super Bot Fight Mode (SBFM) to enable static resource protection.
     * Enable if static resources on your application need bot protection.
     * Note: Static resource protection can also result in legitimate traffic being blocked.
     */
    sbfmStaticResourceProtection?: pulumi.Input<boolean>;
    /**
     * Super Bot Fight Mode (SBFM) action to take on verified bots requests.
     * Available values: "allow", "block".
     */
    sbfmVerifiedBots?: pulumi.Input<string>;
    /**
     * A read-only field that shows which unauthorized settings are currently active on the zone. These settings typically result from upgrades or downgrades.
     */
    staleZoneConfiguration?: pulumi.Input<inputs.BotManagementStaleZoneConfiguration>;
    /**
     * Whether to disable tracking the highest bot score for a session in the Bot Management cookie.
     */
    suppressSessionScore?: pulumi.Input<boolean>;
    /**
     * A read-only field that indicates whether the zone currently is running the latest ML model.
     */
    usingLatestModel?: pulumi.Input<boolean>;
    /**
     * Identifier.
     */
    zoneId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a BotManagement resource.
 */
export interface BotManagementArgs {
    /**
     * Enable rule to block AI Scrapers and Crawlers.
     * Available values: "block", "disabled".
     */
    aiBotsProtection?: pulumi.Input<string>;
    /**
     * Automatically update to the newest bot detection models created by Cloudflare as they are released. [Learn more.](https://developers.cloudflare.com/bots/reference/machine-learning-models#model-versions-and-release-notes)
     */
    autoUpdateModel?: pulumi.Input<boolean>;
    /**
     * Enable rule to punish AI Scrapers and Crawlers via a link maze.
     * Available values: "enabled", "disabled".
     */
    crawlerProtection?: pulumi.Input<string>;
    /**
     * Use lightweight, invisible JavaScript detections to improve Bot Management. [Learn more about JavaScript Detections](https://developers.cloudflare.com/bots/reference/javascript-detections/).
     */
    enableJs?: pulumi.Input<boolean>;
    /**
     * Whether to enable Bot Fight Mode.
     */
    fightMode?: pulumi.Input<boolean>;
    /**
     * Whether to optimize Super Bot Fight Mode protections for Wordpress.
     */
    optimizeWordpress?: pulumi.Input<boolean>;
    /**
     * Super Bot Fight Mode (SBFM) action to take on definitely automated requests.
     * Available values: "allow", "block", "managedChallenge".
     */
    sbfmDefinitelyAutomated?: pulumi.Input<string>;
    /**
     * Super Bot Fight Mode (SBFM) action to take on likely automated requests.
     * Available values: "allow", "block", "managedChallenge".
     */
    sbfmLikelyAutomated?: pulumi.Input<string>;
    /**
     * Super Bot Fight Mode (SBFM) to enable static resource protection.
     * Enable if static resources on your application need bot protection.
     * Note: Static resource protection can also result in legitimate traffic being blocked.
     */
    sbfmStaticResourceProtection?: pulumi.Input<boolean>;
    /**
     * Super Bot Fight Mode (SBFM) action to take on verified bots requests.
     * Available values: "allow", "block".
     */
    sbfmVerifiedBots?: pulumi.Input<string>;
    /**
     * Whether to disable tracking the highest bot score for a session in the Bot Management cookie.
     */
    suppressSessionScore?: pulumi.Input<boolean>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
