import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * > If you are attempting to sign up a subdomain of a zone you must first have Subdomain Support entitlement for your account.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZone = new cloudflare.Zone("example_zone", {
 *     account: {
 *         id: "023e105f4ecef8ad9ca31a8372d0c353",
 *     },
 *     name: "example.com",
 *     type: "full",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/zone:Zone example '<zone_id>'
 * ```
 */
export declare class Zone extends pulumi.CustomResource {
    /**
     * Get an existing Zone resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ZoneState, opts?: pulumi.CustomResourceOptions): Zone;
    /**
     * Returns true if the given object is an instance of Zone.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Zone;
    readonly account: pulumi.Output<outputs.ZoneAccount>;
    /**
     * The last time proof of ownership was detected and the zone was made
     * active
     */
    readonly activatedOn: pulumi.Output<string>;
    /**
     * Allows the customer to use a custom apex.
     * *Tenants Only Configuration*.
     */
    readonly cnameSuffix: pulumi.Output<string>;
    /**
     * When the zone was created
     */
    readonly createdOn: pulumi.Output<string>;
    /**
     * The interval (in seconds) from when development mode expires
     * (positive integer) or last expired (negative integer) for the
     * domain. If development mode has never been enabled, this value is 0.
     */
    readonly developmentMode: pulumi.Output<number>;
    /**
     * Metadata about the zone
     */
    readonly meta: pulumi.Output<outputs.ZoneMeta>;
    /**
     * When the zone was last modified
     */
    readonly modifiedOn: pulumi.Output<string>;
    /**
     * The domain name
     */
    readonly name: pulumi.Output<string>;
    /**
     * The name servers Cloudflare assigns to a zone
     */
    readonly nameServers: pulumi.Output<string[]>;
    /**
     * DNS host at the time of switching to Cloudflare
     */
    readonly originalDnshost: pulumi.Output<string>;
    /**
     * Original name servers before moving to Cloudflare
     */
    readonly originalNameServers: pulumi.Output<string[]>;
    /**
     * Registrar for the domain at the time of switching to Cloudflare
     */
    readonly originalRegistrar: pulumi.Output<string>;
    /**
     * The owner of the zone
     */
    readonly owner: pulumi.Output<outputs.ZoneOwner>;
    /**
     * Indicates whether the zone is only using Cloudflare DNS services. A
     * true value means the zone will not receive security or performance
     * benefits.
     */
    readonly paused: pulumi.Output<boolean>;
    /**
     * Legacy permissions based on legacy user membership information.
     *
     * @deprecated This attribute is deprecated.
     */
    readonly permissions: pulumi.Output<string[]>;
    /**
     * A Zones subscription information.
     *
     * @deprecated This attribute is deprecated.
     */
    readonly plan: pulumi.Output<outputs.ZonePlan>;
    /**
     * The zone status on Cloudflare.
     * Available values: "initializing", "pending", "active", "moved".
     */
    readonly status: pulumi.Output<string>;
    /**
     * The root organizational unit that this zone belongs to (such as a tenant or organization).
     */
    readonly tenant: pulumi.Output<outputs.ZoneTenant>;
    /**
     * The immediate parent organizational unit that this zone belongs to (such as under a tenant or sub-organization).
     */
    readonly tenantUnit: pulumi.Output<outputs.ZoneTenantUnit>;
    /**
     * A full zone implies that DNS is hosted with Cloudflare. A partial zone is
     * typically a partner-hosted zone or a CNAME setup.
     * Available values: "full", "partial", "secondary", "internal".
     */
    readonly type: pulumi.Output<string>;
    /**
     * An array of domains used for custom name servers. This is only
     * available for Business and Enterprise plans.
     */
    readonly vanityNameServers: pulumi.Output<string[] | undefined>;
    /**
     * Verification key for partial zone setup.
     */
    readonly verificationKey: pulumi.Output<string>;
    /**
     * Create a Zone resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ZoneArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Zone resources.
 */
export interface ZoneState {
    account?: pulumi.Input<inputs.ZoneAccount>;
    /**
     * The last time proof of ownership was detected and the zone was made
     * active
     */
    activatedOn?: pulumi.Input<string>;
    /**
     * Allows the customer to use a custom apex.
     * *Tenants Only Configuration*.
     */
    cnameSuffix?: pulumi.Input<string>;
    /**
     * When the zone was created
     */
    createdOn?: pulumi.Input<string>;
    /**
     * The interval (in seconds) from when development mode expires
     * (positive integer) or last expired (negative integer) for the
     * domain. If development mode has never been enabled, this value is 0.
     */
    developmentMode?: pulumi.Input<number>;
    /**
     * Metadata about the zone
     */
    meta?: pulumi.Input<inputs.ZoneMeta>;
    /**
     * When the zone was last modified
     */
    modifiedOn?: pulumi.Input<string>;
    /**
     * The domain name
     */
    name?: pulumi.Input<string>;
    /**
     * The name servers Cloudflare assigns to a zone
     */
    nameServers?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * DNS host at the time of switching to Cloudflare
     */
    originalDnshost?: pulumi.Input<string>;
    /**
     * Original name servers before moving to Cloudflare
     */
    originalNameServers?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Registrar for the domain at the time of switching to Cloudflare
     */
    originalRegistrar?: pulumi.Input<string>;
    /**
     * The owner of the zone
     */
    owner?: pulumi.Input<inputs.ZoneOwner>;
    /**
     * Indicates whether the zone is only using Cloudflare DNS services. A
     * true value means the zone will not receive security or performance
     * benefits.
     */
    paused?: pulumi.Input<boolean>;
    /**
     * Legacy permissions based on legacy user membership information.
     *
     * @deprecated This attribute is deprecated.
     */
    permissions?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A Zones subscription information.
     *
     * @deprecated This attribute is deprecated.
     */
    plan?: pulumi.Input<inputs.ZonePlan>;
    /**
     * The zone status on Cloudflare.
     * Available values: "initializing", "pending", "active", "moved".
     */
    status?: pulumi.Input<string>;
    /**
     * The root organizational unit that this zone belongs to (such as a tenant or organization).
     */
    tenant?: pulumi.Input<inputs.ZoneTenant>;
    /**
     * The immediate parent organizational unit that this zone belongs to (such as under a tenant or sub-organization).
     */
    tenantUnit?: pulumi.Input<inputs.ZoneTenantUnit>;
    /**
     * A full zone implies that DNS is hosted with Cloudflare. A partial zone is
     * typically a partner-hosted zone or a CNAME setup.
     * Available values: "full", "partial", "secondary", "internal".
     */
    type?: pulumi.Input<string>;
    /**
     * An array of domains used for custom name servers. This is only
     * available for Business and Enterprise plans.
     */
    vanityNameServers?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Verification key for partial zone setup.
     */
    verificationKey?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a Zone resource.
 */
export interface ZoneArgs {
    account: pulumi.Input<inputs.ZoneAccount>;
    /**
     * The domain name
     */
    name: pulumi.Input<string>;
    /**
     * A full zone implies that DNS is hosted with Cloudflare. A partial zone is
     * typically a partner-hosted zone or a CNAME setup.
     * Available values: "full", "partial", "secondary", "internal".
     */
    type?: pulumi.Input<string>;
    /**
     * An array of domains used for custom name servers. This is only
     * available for Business and Enterprise plans.
     */
    vanityNameServers?: pulumi.Input<pulumi.Input<string>[]>;
}
